SOURCE_CCADB = 0
SOURCE_JAVA = 1
SOURCE_APPLE = 2
SOURCE_ANDROID = 3
SOURCE_LINUX = 4
PLATFORM_LINUX = SOURCE_LINUX
PLATFORM_JAVA = SOURCE_JAVA
PLATFORM_WINDOWS = SOURCE_CCADB
PLATFORM_APPLE = SOURCE_APPLE
PLATFORM_ANDROID = SOURCE_ANDROID
BROWSER_FIREFOX = SOURCE_CCADB
BROWSER_TOR_BROWSER = SOURCE_CCADB
BROWSER_CHROMIUM = SOURCE_CCADB
BROWSER_GOOGLE_CHROME = SOURCE_CCADB
BROWSER_MICROSOFT_EDGE = SOURCE_CCADB
BROWSER_BRAVE = SOURCE_CCADB
BROWSER_OPERA = SOURCE_CCADB
BROWSER_VIVALDI = SOURCE_CCADB
BROWSER_AMAZON_SILK = SOURCE_CCADB
BROWSER_SAMSUNG_INTERNET_BROWSER = SOURCE_CCADB
BROWSER_YANDEX_BROWSER = SOURCE_CCADB
BROWSER_SAFARI = SOURCE_CCADB
